pub macro debug($($args:tt)*) {
...
}Expand description
Log debug message that includes the enclosing function name in the target
pub macro debug($($args:tt)*) {
...
}Log debug message that includes the enclosing function name in the target