pub macro error($($args:tt)*) {
...
}Expand description
Log error message that includes the enclosing function name in the target
pub macro error($($args:tt)*) {
...
}Log error message that includes the enclosing function name in the target