pub macro trace($($args:tt)*) {
...
}Expand description
Log trace message that includes the enclosing function name in the target
pub macro trace($($args:tt)*) {
...
}Log trace message that includes the enclosing function name in the target