pub macro ebits($e:expr) {
...
}Expand description
Print the stringified expression to stderr followed by its bitstring formatting
pub macro ebits($e:expr) {
...
}Print the stringified expression to stderr followed by its bitstring formatting