pub macro ehex($e:expr) {
...
}Expand description
Print the stringified expression to stderr followed by its hexadecimal formatting
pub macro ehex($e:expr) {
...
}Print the stringified expression to stderr followed by its hexadecimal formatting