min_partial

Function min_partial 

pub fn min_partial<S>(lhs: S, rhs: S) -> S
where S: Copy + PartialOrd,
Returns the minimum of two partially ordered values, returning the rhs when they are incomparable.

This follows the convention of f32::min and f32::max, but the opposite convention is used internally by the collision crate.