Miscellaneous Rust utilities
Modules
Macros
- address
- Print the stringified expression followed by its pointer formatting
- bits
- Print the stringified expression followed by its bitstring formatting
- display
- Print the stringified expression followed by its display formatting
- eaddress
- Print the stringified expression to stderr followed by its pointer formatting
- ebits
- Print the stringified expression to stderr followed by its bitstring formatting
- edisplay
- Print the stringified expression to stderr followed by its display formatting
- ehex
- Print the stringified expression to stderr followed by its hexadecimal formatting
- epretty
- Print the stringified expression to stderr followed by its pretty debug formatting
- eshow
- Print the stringified expression to stderr followed by its debug formatting
- for_
sequence - Expands into a series of for loops with the given block of code which should treat each type uniformly.
- hex
- Print the stringified expression followed by its hexadecimal formatting
- pretty
- Print the stringified expression followed by its pretty debug formatting
- show
- Print the stringified expression followed by its debug formatting